==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.md <==
# AmazonCloudWatchEventTimeBased


```text
aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased
```

```text
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')
```



| Illustration | AmazonCloudWatchEventTimeBased | AmazonCloudWatchEventTimeBasedCard | AmazonCloudWatchEventTimeBasedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.png) | ![illustration for AmazonCloudWatchEventTimeBased](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedCard](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedCard.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedGroup](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedGroup.Local.png) |




## AmazonCloudWatchEventTimeBased

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

## AmazonCloudWatchEventTimeBasedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

## AmazonCloudWatchEventTimeBasedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.md <==
# AmazonCloudWatchEventTimeBased


```text
aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased
```

```text
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')
```



| Illustration | AmazonCloudWatchEventTimeBased | AmazonCloudWatchEventTimeBasedCard | AmazonCloudWatchEventTimeBasedGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.png) | ![illustration for AmazonCloudWatchEventTimeBased](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedCard](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedCard.Local.png) | ![illustration for AmazonCloudWatchEventTimeBasedGroup](../../../aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBasedGroup.Local.png) |




## AmazonCloudWatchEventTimeBased

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBased
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBased('AmazonCloudWatchEventTimeBased', 'Amazon Cloud Watch Event Time Based', 'an optional tech label')
@enduml
```

## AmazonCloudWatchEventTimeBasedCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedCard
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedCard('AmazonCloudWatchEventTimeBasedCard', 'Amazon Cloud Watch Event Time Based Card', 'an optional description')
@enduml
```

## AmazonCloudWatchEventTimeBasedGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchEventTimeBasedGroup
include('aws-20210730/Resource/ManagementGovernance/AmazonCloudWatchEventTimeBased')

' renders the element
AmazonCloudWatchEventTimeBasedGroup('AmazonCloudWatchEventTimeBasedGroup', 'Amazon Cloud Watch Event Time Based Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
